@@ -1,9 +1,9 @@
-from zemfrog.decorators import auto_status_code, authenticate
-from zemfrog.helper import db_add, db_delete, db_update, get_column_names
+from zemfrog.decorators import http_code, authenticate
+from zemfrog.helper import db_add, db_delete, db_update
 from zemfrog.models import DefaultResponseSchema
 from flask_apispec import marshal_with, use_kwargs
 from marshmallow import fields
-from {{ "" if main_app else ".." }}extensions.marshmallow import ma
+from zemfrog.globals import ma
 from {{ "" if main_app else ".." }}{{src_model}} import {{name}}
 
 class Create{{name}}Schema(ma.SQLAlchemyAutoSchema):
@@ -25,57 +25,29 @@ class Update{{name}}Schema(ma.SQLAlchemyAutoSchema):
 #         model = {{name}}
 
 class Limit{{name}}Schema(ma.Schema):
-    start = fields.Integer()
-    stop = fields.Integer()
-    q = fields.String()
-    filters = fields.List(fields.String())
+    offset = fields.Integer()
+    limit = fields.Integer()
 
 
-@authenticate()
-@marshal_with(Read{{name}}Schema(), 200)
-def get(id):
-    """
-    Get one data based on the model's primary key.
-    """
-
-    data = {{name}}.query.get(id)
-    return data
-
 @authenticate()
 @use_kwargs(Limit{{name}}Schema(), location="query")
 @marshal_with(Read{{name}}Schema(many=True), 200)
-def list(**kwds):
+def read(**kwds):
     """
     Read all data.
     """
 
-    start = kwds.get("start")
-    stop = kwds.get("stop")
-    q = kwds.get("q")
-    data = {{name}}.query[start:stop]
-    if not q:
-        return data
-
-    columns = get_column_names({{name}})
-    filters = filter(lambda value: value in columns, kwds.get("filters"))
-    if not filters:
-        filters = columns
-
-    new_data = []
-    for d in data:
-        for f in filters:
-            v = str(getattr(d, f))
-            if q in v:
-                new_data.append(d)
-
-    return new_data
+    offset = kwds.get("offset")
+    limit = kwds.get("limit")
+    data = {{name}}.query.offset(offset).limit(limit).all()
+    return data
 
 @authenticate()
 @use_kwargs(Create{{name}}Schema())
 @marshal_with(DefaultResponseSchema, 200)
 @marshal_with(DefaultResponseSchema, 403)
-@auto_status_code
-def add(**kwds):
+@http_code
+def create(**kwds):
     """
     Add data.
     """
@@ -85,22 +57,22 @@ def add(**kwds):
         model = {{name}}(**kwds)
         db_add(model)
         status_code = 200
-        reason = "Successfully added data."
+        message = "Successfully added data."
 
     else:
         status_code = 403
-        reason = "Data already exists."
+        message = "Data already exists."
 
     return {
-        "status_code": status_code,
-        "reason": reason
+        "code": status_code,
+        "message": message
     }
 
 @authenticate()
 @use_kwargs(Update{{name}}Schema())
 @marshal_with(DefaultResponseSchema, 200)
 @marshal_with(DefaultResponseSchema, 404)
-@auto_status_code
+@http_code
 def update(id, **kwds):
     """
     Update data.
@@ -110,22 +82,22 @@ def update(id, **kwds):
     if model:
         db_update(model, **kwds)
         status_code = 200
-        reason = "Successfully updating data."
+        message = "Successfully updating data."
 
     else:
         status_code = 404
-        reason = "Data not found."
+        message = "Data not found."
 
     return {
-        "status_code": status_code,
-        "reason": reason
+        "code": status_code,
+        "message": message
     }
 
 @authenticate()
 # @use_kwargs(Delete{{name}}Schema())
 @marshal_with(DefaultResponseSchema, 200)
 @marshal_with(DefaultResponseSchema, 404)
-@auto_status_code
+@http_code
 def delete(id):
     """
     Delete data.
@@ -135,25 +107,24 @@ def delete(id):
     if model:
         db_delete(model)
         status_code = 200
-        reason = "Data deleted successfully."
+        message = "Data deleted successfully."
 
     else:
         status_code = 404
-        reason = "Data not found."
+        message = "Data not found."
 
     return {
-        "status_code": status_code,
-        "reason": reason
+        "code": status_code,
+        "message": message
     }
 
 
 docs = {"tags": ["{{name}}"]}
-endpoint = "{{url_prefix}}"
-url_prefix = "/{{url_prefix}}"
+endpoint = "{{url_prefix | lower}}"
+url_prefix = "/{{url_prefix | lower}}"
 routes = [
-    ("/get/<id>", get, ["GET"]),
-    ("/list", list, ["GET"]),
-    ("/add", add, ["POST"]),
+    ("/create", create, ["POST"]),
+    ("/read", read, ["GET"]),
     ("/update/<id>", update, ["PUT"]),
     ("/delete/<id>", delete, ["DELETE"])
 ]
